@@ -1,46 +1,16 @@
-from __future__ import absolute_import, division, unicode_literals
-
 import cProfile
 import os
 from colorsys import hsv_to_rgb
 from pstats import Stats
 
-from django.utils import six
 from django.utils.html import format_html
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from debug_toolbar import settings as dt_settings
 from debug_toolbar.panels import Panel
 
-# Occasionally the disable method on the profiler is listed before
-# the actual view functions. This function call should be ignored as
-# it leads to an error within the tests.
-INVALID_PROFILER_FUNC = "_lsprof.Profiler"
 
-
-def contains_profiler(func_tuple):
-    """Helper function that checks to see if the tuple contains
-    the INVALID_PROFILE_FUNC in any string value of the tuple."""
-    has_profiler = False
-    for value in func_tuple:
-        if isinstance(value, six.string_types):
-            has_profiler |= INVALID_PROFILER_FUNC in value
-    return has_profiler
-
-
-class DjangoDebugToolbarStats(Stats):
-    __root = None
-
-    def get_root_func(self):
-        if self.__root is None:
-            for func, (cc, nc, tt, ct, callers) in self.stats.items():
-                if len(callers) == 0 and not contains_profiler(func):
-                    self.__root = func
-                    break
-        return self.__root
-
-
-class FunctionCall(object):
+class FunctionCall:
     def __init__(
         self, statobj, func, depth=0, stats=None, id=0, parent_ids=[], hsv=(0, 0.5, 1)
     ):
@@ -60,7 +30,7 @@ class FunctionCall(object):
 
     def background(self):
         r, g, b = hsv_to_rgb(*self.hsv)
-        return "rgb(%f%%,%f%%,%f%%)" % (r * 100, g * 100, b * 100)
+        return f"rgb({r * 100:f}%,{g * 100:f}%,{b * 100:f}%)"
 
     def func_std_string(self):  # match what old profile produced
         func_name = self.func
@@ -154,10 +124,9 @@ class ProfilingPanel(Panel):
 
     template = "debug_toolbar/panels/profiling.html"
 
-    def process_view(self, request, view_func, view_args, view_kwargs):
+    def process_request(self, request):
         self.profiler = cProfile.Profile()
-        args = (request,) + view_args
-        return self.profiler.runcall(view_func, *args, **view_kwargs)
+        return self.profiler.runcall(super().process_request, request)
 
     def add_node(self, func_list, func, max_depth, cum_time=0.1):
         func_list.append(func)
@@ -173,12 +142,12 @@ class ProfilingPanel(Panel):
             return None
         # Could be delayed until the panel content is requested (perf. optim.)
         self.profiler.create_stats()
-        self.stats = DjangoDebugToolbarStats(self.profiler)
+        self.stats = Stats(self.profiler)
         self.stats.calc_callees()
 
-        root_func = self.stats.get_root_func()
-        # Ensure root function exists before continuing with function call analysis
-        if root_func:
+        root_func = cProfile.label(super().process_request.__code__)
+
+        if root_func in self.stats.stats:
             root = FunctionCall(self.stats, root_func, depth=0)
             func_list = []
             self.add_node(
